Struct microbit::hal::clocks::Clocks [−][src]
pub struct Clocks<H, L, LSTAT> { /* fields omitted */ }Expand description
A high level abstraction for the CLOCK peripheral.
Implementations
impl Clocks<Internal, Internal, LfOscStopped>[src]
impl Clocks<Internal, Internal, LfOscStopped>[src]impl<H, L, LSTAT> Clocks<H, L, LSTAT>[src]
impl<H, L, LSTAT> Clocks<H, L, LSTAT>[src]pub fn enable_ext_hfosc(self) -> Clocks<ExternalOscillator, L, LSTAT>[src]
pub fn enable_ext_hfosc(self) -> Clocks<ExternalOscillator, L, LSTAT>[src]Use an external oscillator as the high frequency clock source.
pub fn disable_ext_hfosc(self) -> Clocks<Internal, L, LSTAT>[src]
pub fn disable_ext_hfosc(self) -> Clocks<Internal, L, LSTAT>[src]Use the internal oscillator as the high frequency clock source.
pub fn start_lfclk(self) -> Clocks<H, L, LfOscStarted>[src]
pub fn start_lfclk(self) -> Clocks<H, L, LfOscStarted>[src]Start the Low Frequency clock.
impl<H, L> Clocks<H, L, LfOscStarted>[src]
impl<H, L> Clocks<H, L, LfOscStarted>[src]pub fn stop_lfclk(self) -> Clocks<H, L, LfOscStopped>[src]
pub fn stop_lfclk(self) -> Clocks<H, L, LfOscStopped>[src]Stop the Low Frequency clock.
impl<H, L> Clocks<H, L, LfOscStopped>[src]
impl<H, L> Clocks<H, L, LfOscStopped>[src]pub fn set_lfclk_src_rc(self) -> Clocks<H, Internal, LfOscStopped>[src]
pub fn set_lfclk_src_rc(self) -> Clocks<H, Internal, LfOscStopped>[src]Use the internal RC Oscillator for the low frequency clock source.
pub fn set_lfclk_src_synth(self) -> Clocks<H, LfOscSynthesized, LfOscStopped>[src]
pub fn set_lfclk_src_synth(self) -> Clocks<H, LfOscSynthesized, LfOscStopped>[src]Generate the Low Frequency clock from the high frequency clock source.
pub fn set_lfclk_src_external(
self,
cfg: LfOscConfiguration
) -> Clocks<H, ExternalOscillator, LfOscStopped>[src]
pub fn set_lfclk_src_external(
self,
cfg: LfOscConfiguration
) -> Clocks<H, ExternalOscillator, LfOscStopped>[src]Use an external crystal to drive the low frequency clock.