Struct microbit::hal::comp::Comp [−][src]
pub struct Comp { /* fields omitted */ }Expand description
A safe wrapper around the COMP peripheral.
Implementations
impl Comp[src]
impl Comp[src]pub fn new<P>(comp: COMP, input_pin: &P) -> Comp where
P: CompInputPin, [src]
pub fn new<P>(comp: COMP, input_pin: &P) -> Comp where
P: CompInputPin, [src]Takes ownership of the COMP peripheral, returning a safe wrapper.
pub fn power_mode(&self, mode: PowerMode) -> &Comp[src]
pub fn power_mode(&self, mode: PowerMode) -> &Comp[src]Sets the speed and power mode of the comparator.
pub fn aref_pin<P>(&self, ref_pin: &P) -> &Comp where
P: CompRefPin, [src]
pub fn aref_pin<P>(&self, ref_pin: &P) -> &Comp where
P: CompRefPin, [src]Sets analog reference pin.
pub fn differential<P>(&self, ref_pin: &P) -> &Comp where
P: CompRefPin, [src]
pub fn differential<P>(&self, ref_pin: &P) -> &Comp where
P: CompRefPin, [src]Sets comparator mode to differential with external Vref pin.
pub fn hysteresis_threshold_up(&self, value: u8) -> &Comp[src]
pub fn hysteresis_threshold_up(&self, value: u8) -> &Comp[src]Upward hysteresis threshold in single ended mode Vup = (value+1)/64*Vref.
pub fn hysteresis_threshold_down(&self, value: u8) -> &Comp[src]
pub fn hysteresis_threshold_down(&self, value: u8) -> &Comp[src]Downward hysteresis threshold in single ended mode Vdown = (value+1)/64*Vref.
pub fn hysteresis(&self, enabled: bool) -> &Comp[src]
pub fn hysteresis(&self, enabled: bool) -> &Comp[src]Enables/disables differential comparator hysteresis (50mV).
pub fn enable_interrupt(&self, event: Transition) -> &Comp[src]
pub fn enable_interrupt(&self, event: Transition) -> &Comp[src]Enables COMP_LPCOMP interrupt triggering on the specified event.
pub fn disable_interrupt(&self, event: Transition) -> &Comp[src]
pub fn disable_interrupt(&self, event: Transition) -> &Comp[src]Disables COMP_LPCOMP interrupt triggering on the specified event.
pub fn event_up(&self) -> &Reg<u32, _EVENTS_UP>[src]
pub fn event_up(&self) -> &Reg<u32, _EVENTS_UP>[src]Returns reference to Up transition event endpoint for PPI.
pub fn event_down(&self) -> &Reg<u32, _EVENTS_DOWN>[src]
pub fn event_down(&self) -> &Reg<u32, _EVENTS_DOWN>[src]Returns reference to Down transition event endpoint for PPI.
pub fn event_cross(&self) -> &Reg<u32, _EVENTS_CROSS>[src]
pub fn event_cross(&self) -> &Reg<u32, _EVENTS_CROSS>[src]Returns reference to Cross transition event endpoint for PPI.
pub fn reset_event(&self, event: Transition)[src]
pub fn reset_event(&self, event: Transition)[src]Marks event as handled.
pub fn reset_events(&self)[src]
pub fn reset_events(&self)[src]Marks all events as handled.
pub fn read(&self) -> CompResult[src]
pub fn read(&self) -> CompResult[src]Returns the output state of the comparator.