pub enum Cca {
    CarrierSense,
    EnergyDetection {
        ed_threshold: u8,
    },
}
Clear Channel Assessment method

Variants

CarrierSense

Carrier sense

EnergyDetection

Fields

ed_threshold: u8

Energy measurements above this value mean that the channel is assumed to be busy. Note the the measurement range is 0..0xFF - where 0 means that the received power was less than 10 dB above the selected receiver sensitivity. This value is not given in dBm, but can be converted. See the nrf52840 Product Specification Section 6.20.12.4 for details.

Energy Detection / Energy Above Threshold