Struct microbit::hal::lpcomp::LpComp [−][src]
pub struct LpComp { /* fields omitted */ }Expand description
A safe wrapper around the LPCOMP peripheral.
Implementations
impl LpComp[src]
impl LpComp[src]pub fn new<P>(lpcomp: LPCOMP, input_pin: &P) -> LpComp where
P: LpCompInputPin, [src]
pub fn new<P>(lpcomp: LPCOMP, input_pin: &P) -> LpComp where
P: LpCompInputPin, [src]Takes ownership of the LPCOMP peripheral, returning a safe wrapper
using specified input pin and a default Vref of Vdd/2.
pub fn aref_pin<P>(&self, ref_pin: &P) -> &LpComp where
P: LpCompRefPin, [src]
pub fn aref_pin<P>(&self, ref_pin: &P) -> &LpComp where
P: LpCompRefPin, [src]Sets analog reference pin.
pub fn hysteresis(&self, enabled: bool) -> &LpComp[src]
pub fn hysteresis(&self, enabled: bool) -> &LpComp[src]Enables/disables comparator hysteresis.
pub fn analog_detect(&self, event: Transition) -> &LpComp[src]
pub fn analog_detect(&self, event: Transition) -> &LpComp[src]Analog detect event configuration, used for analog signal power up from OFF.
pub fn enable_interrupt(&self, event: Transition) -> &LpComp[src]
pub fn enable_interrupt(&self, event: Transition) -> &LpComp[src]Enables COMP_LPCOMP interrupt triggering on the specified event.
pub fn disable_interrupt(&self, event: Transition) -> &LpComp[src]
pub fn disable_interrupt(&self, event: Transition) -> &LpComp[src]Disables COMP_LPCOMP interrupt triggering on the specified event.
pub fn event_up(&self) -> &Reg<u32, _EVENTS_UP>[src]
pub fn event_up(&self) -> &Reg<u32, _EVENTS_UP>[src]Returns reference to Up transition event endpoint for PPI.
pub fn event_down(&self) -> &Reg<u32, _EVENTS_DOWN>[src]
pub fn event_down(&self) -> &Reg<u32, _EVENTS_DOWN>[src]Returns reference to Down transition event endpoint for PPI.
pub fn event_cross(&self) -> &Reg<u32, _EVENTS_CROSS>[src]
pub fn event_cross(&self) -> &Reg<u32, _EVENTS_CROSS>[src]Returns reference to Cross transition event endpoint for PPI.
pub fn reset_event(&self, event: Transition)[src]
pub fn reset_event(&self, event: Transition)[src]Marks event as handled.
pub fn reset_events(&self)[src]
pub fn reset_events(&self)[src]Marks all events as handled.
pub fn read(&self) -> CompResult[src]
pub fn read(&self) -> CompResult[src]Returns the output state of the comparator.