Module microbit::hal::pac::aar [−]
Accelerated Address Resolver
Modules
| addrptr | Pointer to the resolvable address |
| enable | Enable AAR |
| events_end | Address resolution procedure complete |
| events_notresolved | Address not resolved |
| events_resolved | Address resolved |
| intenclr | Disable interrupt |
| intenset | Enable interrupt |
| irkptr | Pointer to IRK data structure |
| nirk | Number of IRKs |
| scratchptr | Pointer to data area used for temporary storage |
| status | Resolution status |
| tasks_start | Start resolving addresses based on IRKs specified in the IRK data structure |
| tasks_stop | Stop resolving addresses |
Structs
| RegisterBlock | Register block |
Type Definitions
| ADDRPTR | Pointer to the resolvable address |
| ENABLE | Enable AAR |
| EVENTS_END | Address resolution procedure complete |
| EVENTS_NOTRESOLVED | Address not resolved |
| EVENTS_RESOLVED | Address resolved |
| INTENCLR | Disable interrupt |
| INTENSET | Enable interrupt |
| IRKPTR | Pointer to IRK data structure |
| NIRK | Number of IRKs |
| SCRATCHPTR | Pointer to data area used for temporary storage |
| STATUS | Resolution status |
| TASKS_START | Start resolving addresses based on IRKs specified in the IRK data structure |
| TASKS_STOP | Stop resolving addresses |