Module microbit::hal::pac::clock [−]
Clock control
Modules
| ctiv | Calibration timer interval |
| events_ctstarted | Calibration timer has been started and is ready to process new tasks |
| events_ctstopped | Calibration timer has been stopped and is ready to process new tasks |
| events_ctto | Calibration timer timeout |
| events_done | Calibration of LFRC completed |
| events_hfclkstarted | HFXO crystal oscillator started |
| events_lfclkstarted | LFCLK started |
| hfclkrun | Status indicating that HFCLKSTART task has been triggered |
| hfclkstat | HFCLK status |
| hfxodebounce | HFXO debounce time. The HFXO is started by triggering the TASKS_HFCLKSTART task. |
| intenclr | Disable interrupt |
| intenset | Enable interrupt |
| lfclkrun | Status indicating that LFCLKSTART task has been triggered |
| lfclksrc | Clock source for the LFCLK |
| lfclksrccopy | Copy of LFCLKSRC register, set when LFCLKSTART task was triggered |
| lfclkstat | LFCLK status |
| lfxodebounce | LFXO debounce time. The LFXO is started by triggering the TASKS_LFCLKSTART task when the LFCLKSRC register is configured for Xtal. |
| tasks_cal | Start calibration of LFRC |
| tasks_ctstart | Start calibration timer |
| tasks_ctstop | Stop calibration timer |
| tasks_hfclkstart | Start HFXO crystal oscillator |
| tasks_hfclkstop | Stop HFXO crystal oscillator |
| tasks_lfclkstart | Start LFCLK |
| tasks_lfclkstop | Stop LFCLK |
| traceconfig | Clocking options for the trace port debug interface |
Structs
| RegisterBlock | Register block |
Type Definitions
| CTIV | Calibration timer interval |
| EVENTS_CTSTARTED | Calibration timer has been started and is ready to process new tasks |
| EVENTS_CTSTOPPED | Calibration timer has been stopped and is ready to process new tasks |
| EVENTS_CTTO | Calibration timer timeout |
| EVENTS_DONE | Calibration of LFRC completed |
| EVENTS_HFCLKSTARTED | HFXO crystal oscillator started |
| EVENTS_LFCLKSTARTED | LFCLK started |
| HFCLKRUN | Status indicating that HFCLKSTART task has been triggered |
| HFCLKSTAT | HFCLK status |
| HFXODEBOUNCE | HFXO debounce time. The HFXO is started by triggering the TASKS_HFCLKSTART task. |
| INTENCLR | Disable interrupt |
| INTENSET | Enable interrupt |
| LFCLKRUN | Status indicating that LFCLKSTART task has been triggered |
| LFCLKSRC | Clock source for the LFCLK |
| LFCLKSRCCOPY | Copy of LFCLKSRC register, set when LFCLKSTART task was triggered |
| LFCLKSTAT | LFCLK status |
| LFXODEBOUNCE | LFXO debounce time. The LFXO is started by triggering the TASKS_LFCLKSTART task when the LFCLKSRC register is configured for Xtal. |
| TASKS_CAL | Start calibration of LFRC |
| TASKS_CTSTART | Start calibration timer |
| TASKS_CTSTOP | Stop calibration timer |
| TASKS_HFCLKSTART | Start HFXO crystal oscillator |
| TASKS_HFCLKSTOP | Stop HFXO crystal oscillator |
| TASKS_LFCLKSTART | Start LFCLK |
| TASKS_LFCLKSTOP | Stop LFCLK |
| TRACECONFIG | Clocking options for the trace port debug interface |