#[repr(C)]pub struct RegisterBlock {Show 25 fields
pub tasks_hfclkstart: Reg<TASKS_HFCLKSTART_SPEC>,
pub tasks_hfclkstop: Reg<TASKS_HFCLKSTOP_SPEC>,
pub tasks_lfclkstart: Reg<TASKS_LFCLKSTART_SPEC>,
pub tasks_lfclkstop: Reg<TASKS_LFCLKSTOP_SPEC>,
pub tasks_cal: Reg<TASKS_CAL_SPEC>,
pub tasks_ctstart: Reg<TASKS_CTSTART_SPEC>,
pub tasks_ctstop: Reg<TASKS_CTSTOP_SPEC>,
pub events_hfclkstarted: Reg<EVENTS_HFCLKSTARTED_SPEC>,
pub events_lfclkstarted: Reg<EVENTS_LFCLKSTARTED_SPEC>,
pub events_done: Reg<EVENTS_DONE_SPEC>,
pub events_ctto: Reg<EVENTS_CTTO_SPEC>,
pub events_ctstarted: Reg<EVENTS_CTSTARTED_SPEC>,
pub events_ctstopped: Reg<EVENTS_CTSTOPPED_SPEC>,
pub intenset: Reg<INTENSET_SPEC>,
pub intenclr: Reg<INTENCLR_SPEC>,
pub hfclkrun: Reg<HFCLKRUN_SPEC>,
pub hfclkstat: Reg<HFCLKSTAT_SPEC>,
pub lfclkrun: Reg<LFCLKRUN_SPEC>,
pub lfclkstat: Reg<LFCLKSTAT_SPEC>,
pub lfclksrccopy: Reg<LFCLKSRCCOPY_SPEC>,
pub lfclksrc: Reg<LFCLKSRC_SPEC>,
pub hfxodebounce: Reg<HFXODEBOUNCE_SPEC>,
pub lfxodebounce: Reg<LFXODEBOUNCE_SPEC>,
pub ctiv: Reg<CTIV_SPEC>,
pub traceconfig: Reg<TRACECONFIG_SPEC>,
/* private fields */
}Expand description
Register block
Fields
tasks_hfclkstart: Reg<TASKS_HFCLKSTART_SPEC>0x00 - Start HFXO crystal oscillator
tasks_hfclkstop: Reg<TASKS_HFCLKSTOP_SPEC>0x04 - Stop HFXO crystal oscillator
tasks_lfclkstart: Reg<TASKS_LFCLKSTART_SPEC>0x08 - Start LFCLK
tasks_lfclkstop: Reg<TASKS_LFCLKSTOP_SPEC>0x0c - Stop LFCLK
tasks_cal: Reg<TASKS_CAL_SPEC>0x10 - Start calibration of LFRC
tasks_ctstart: Reg<TASKS_CTSTART_SPEC>0x14 - Start calibration timer
tasks_ctstop: Reg<TASKS_CTSTOP_SPEC>0x18 - Stop calibration timer
events_hfclkstarted: Reg<EVENTS_HFCLKSTARTED_SPEC>0x100 - HFXO crystal oscillator started
events_lfclkstarted: Reg<EVENTS_LFCLKSTARTED_SPEC>0x104 - LFCLK started
events_done: Reg<EVENTS_DONE_SPEC>0x10c - Calibration of LFRC completed
events_ctto: Reg<EVENTS_CTTO_SPEC>0x110 - Calibration timer timeout
events_ctstarted: Reg<EVENTS_CTSTARTED_SPEC>0x128 - Calibration timer has been started and is ready to process new tasks
events_ctstopped: Reg<EVENTS_CTSTOPPED_SPEC>0x12c - Calibration timer has been stopped and is ready to process new tasks
intenset: Reg<INTENSET_SPEC>0x304 - Enable interrupt
intenclr: Reg<INTENCLR_SPEC>0x308 - Disable interrupt
hfclkrun: Reg<HFCLKRUN_SPEC>0x408 - Status indicating that HFCLKSTART task has been triggered
hfclkstat: Reg<HFCLKSTAT_SPEC>0x40c - HFCLK status
lfclkrun: Reg<LFCLKRUN_SPEC>0x414 - Status indicating that LFCLKSTART task has been triggered
lfclkstat: Reg<LFCLKSTAT_SPEC>0x418 - LFCLK status
lfclksrccopy: Reg<LFCLKSRCCOPY_SPEC>0x41c - Copy of LFCLKSRC register, set when LFCLKSTART task was triggered
lfclksrc: Reg<LFCLKSRC_SPEC>0x518 - Clock source for the LFCLK
hfxodebounce: Reg<HFXODEBOUNCE_SPEC>0x528 - HFXO debounce time. The HFXO is started by triggering the TASKS_HFCLKSTART task.
lfxodebounce: Reg<LFXODEBOUNCE_SPEC>0x52c - LFXO debounce time. The LFXO is started by triggering the TASKS_LFCLKSTART task when the LFCLKSRC register is configured for Xtal.
ctiv: Reg<CTIV_SPEC>0x538 - Calibration timer interval
traceconfig: Reg<TRACECONFIG_SPEC>0x55c - Clocking options for the trace port debug interface