Module microbit::hal::pac::egu0[]

Event generator unit 0

Modules

Description collection: Event number n generated by triggering the corresponding TRIGGER[n] task

Enable or disable interrupt

Disable interrupt

Enable interrupt

Description collection: Trigger n for triggering the corresponding TRIGGERED[n] event

Structs

Register block

Type Definitions

Description collection: Event number n generated by triggering the corresponding TRIGGER[n] task

Enable or disable interrupt

Disable interrupt

Enable interrupt

Description collection: Trigger n for triggering the corresponding TRIGGERED[n] event