Enables the modulation output to a GPIO pin which can be connected to a second external antenna.

Structs

Field MODULATIONCTRL reader - Configuration of modulation control.

Enables the modulation output to a GPIO pin which can be connected to a second external antenna.

Field MODULATIONCTRL writer - Configuration of modulation control.

Register MODULATIONCTRL reader

Register MODULATIONCTRL writer

Enums

Configuration of modulation control.