Module microbit::hal::pac::pdm [−]
Pulse Density Modulation (Digital Microphone) Interface
Modules
| enable | PDM module enable register |
| events_end | The PDM has written the last sample specified by SAMPLE.MAXCNT (or the last sample after a STOP task has been received) to Data RAM |
| events_started | PDM transfer has started |
| events_stopped | PDM transfer has finished |
| gainl | Left output gain adjustment |
| gainr | Right output gain adjustment |
| inten | Enable or disable interrupt |
| intenclr | Disable interrupt |
| intenset | Enable interrupt |
| mode | Defines the routing of the connected PDM microphones’ signals |
| pdmclkctrl | PDM clock generator control |
| psel | Register block Unspecified |
| ratio | Selects the ratio between PDM_CLK and output sample rate. Change PDMCLKCTRL accordingly. |
| sample | Register block Unspecified |
| tasks_start | Starts continuous PDM transfer |
| tasks_stop | Stops PDM transfer |
Structs
| PSEL | Register block |
| RegisterBlock | Register block |
| SAMPLE | Register block |
Type Definitions
| ENABLE | PDM module enable register |
| EVENTS_END | The PDM has written the last sample specified by SAMPLE.MAXCNT (or the last sample after a STOP task has been received) to Data RAM |
| EVENTS_STARTED | PDM transfer has started |
| EVENTS_STOPPED | PDM transfer has finished |
| GAINL | Left output gain adjustment |
| GAINR | Right output gain adjustment |
| INTEN | Enable or disable interrupt |
| INTENCLR | Disable interrupt |
| INTENSET | Enable interrupt |
| MODE | Defines the routing of the connected PDM microphones’ signals |
| PDMCLKCTRL | PDM clock generator control |
| RATIO | Selects the ratio between PDM_CLK and output sample rate. Change PDMCLKCTRL accordingly. |
| TASKS_START | Starts continuous PDM transfer |
| TASKS_STOP | Stops PDM transfer |