pub struct R(/* private fields */);Expand description
Register POFCON reader
Implementations
Sourceimpl R
impl R
Sourcepub fn threshold(&self) -> FieldReaderRaw<u8, THRESHOLD_A>
pub fn threshold(&self) -> FieldReaderRaw<u8, THRESHOLD_A>
Bits 1:4 - Power-fail comparator threshold setting. This setting applies both for normal voltage mode (supply connected to both VDD and VDDH) and high voltage mode (supply connected to VDDH only). Values 0-3 set threshold below 1.7 V and should not be used as brown out detection will be activated before power failure warning on such low voltages.
Sourcepub fn thresholdvddh(&self) -> FieldReaderRaw<u8, THRESHOLDVDDH_A>
pub fn thresholdvddh(&self) -> FieldReaderRaw<u8, THRESHOLDVDDH_A>
Bits 8:11 - Power-fail comparator threshold setting for high voltage mode (supply connected to VDDH only). This setting does not apply for normal voltage mode (supply connected to both VDD and VDDH).
Methods from Deref<Target = R<POFCON_SPEC>>
Sourcepub fn bits(&self) -> <REG as RegisterSpec>::Ux
pub fn bits(&self) -> <REG as RegisterSpec>::Ux
Reads raw bits from register.