pub struct RegisterBlock {Show 21 fields
pub tasks_start: Reg<TASKS_START_SPEC>,
pub tasks_sample: Reg<TASKS_SAMPLE_SPEC>,
pub tasks_stop: Reg<TASKS_STOP_SPEC>,
pub tasks_calibrateoffset: Reg<TASKS_CALIBRATEOFFSET_SPEC>,
pub events_started: Reg<EVENTS_STARTED_SPEC>,
pub events_end: Reg<EVENTS_END_SPEC>,
pub events_done: Reg<EVENTS_DONE_SPEC>,
pub events_resultdone: Reg<EVENTS_RESULTDONE_SPEC>,
pub events_calibratedone: Reg<EVENTS_CALIBRATEDONE_SPEC>,
pub events_stopped: Reg<EVENTS_STOPPED_SPEC>,
pub events_ch: [EVENTS_CH; 8],
pub inten: Reg<INTEN_SPEC>,
pub intenset: Reg<INTENSET_SPEC>,
pub intenclr: Reg<INTENCLR_SPEC>,
pub status: Reg<STATUS_SPEC>,
pub enable: Reg<ENABLE_SPEC>,
pub ch: [CH; 8],
pub resolution: Reg<RESOLUTION_SPEC>,
pub oversample: Reg<OVERSAMPLE_SPEC>,
pub samplerate: Reg<SAMPLERATE_SPEC>,
pub result: RESULT,
/* private fields */
}Expand description
Register block
Fields
tasks_start: Reg<TASKS_START_SPEC>0x00 - Starts the SAADC and prepares the result buffer in RAM
tasks_sample: Reg<TASKS_SAMPLE_SPEC>0x04 - Takes one SAADC sample
tasks_stop: Reg<TASKS_STOP_SPEC>0x08 - Stops the SAADC and terminates all on-going conversions
tasks_calibrateoffset: Reg<TASKS_CALIBRATEOFFSET_SPEC>0x0c - Starts offset auto-calibration
events_started: Reg<EVENTS_STARTED_SPEC>0x100 - The SAADC has started
events_end: Reg<EVENTS_END_SPEC>0x104 - The SAADC has filled up the result buffer
events_done: Reg<EVENTS_DONE_SPEC>0x108 - A conversion task has been completed. Depending on the configuration, multiple conversions might be needed for a result to be transferred to RAM.
events_resultdone: Reg<EVENTS_RESULTDONE_SPEC>0x10c - Result ready for transfer to RAM
events_calibratedone: Reg<EVENTS_CALIBRATEDONE_SPEC>0x110 - Calibration is complete
events_stopped: Reg<EVENTS_STOPPED_SPEC>0x114 - The SAADC has stopped
events_ch: [EVENTS_CH; 8]0x118..0x158 - Peripheral events.
inten: Reg<INTEN_SPEC>0x300 - Enable or disable interrupt
intenset: Reg<INTENSET_SPEC>0x304 - Enable interrupt
intenclr: Reg<INTENCLR_SPEC>0x308 - Disable interrupt
status: Reg<STATUS_SPEC>0x400 - Status
enable: Reg<ENABLE_SPEC>0x500 - Enable or disable SAADC
ch: [CH; 8]0x510..0x590 - Unspecified
resolution: Reg<RESOLUTION_SPEC>0x5f0 - Resolution configuration
oversample: Reg<OVERSAMPLE_SPEC>0x5f4 - Oversampling configuration. The RESOLUTION is applied before averaging, thus for high OVERSAMPLE a higher RESOLUTION should be used.
samplerate: Reg<SAMPLERATE_SPEC>0x5f8 - Controls normal or continuous sample rate
result: RESULT0x62c..0x638 - RESULT EasyDMA channel