Struct microbit::hal::pac::CPUID [−]
pub struct CPUID { /* fields omitted */ }Expand description
CPUID
Implementations
impl CPUID
impl CPUIDpub fn select_cache(&mut self, level: u8, ind: CsselrCacheType)
pub fn select_cache(&mut self, level: u8, ind: CsselrCacheType)Selects the current CCSIDR
level: the required cache level minus 1, e.g. 0 for L1, 1 for L2ind: select instruction cache or data/unified cache
level is masked to be between 0 and 7.
pub fn cache_num_sets_ways(
&mut self,
level: u8,
ind: CsselrCacheType
) -> (u16, u16)
pub fn cache_num_sets_ways(
&mut self,
level: u8,
ind: CsselrCacheType
) -> (u16, u16)Returns the number of sets and ways in the selected cache
pub fn cache_dminline() -> u32
pub fn cache_dminline() -> u32Returns log2 of the number of words in the smallest cache line of all the data cache and unified caches that are controlled by the processor.
This is the DminLine field of the CTR register.
pub fn cache_iminline() -> u32
pub fn cache_iminline() -> u32Returns log2 of the number of words in the smallest cache line of all the instruction caches that are controlled by the processor.
This is the IminLine field of the CTR register.
impl CPUID
impl CPUIDTrait Implementations