Module microbit::hal::pac::usbd [−]
Universal serial bus device
Modules
| bmrequesttype | SETUP data, byte 0, bmRequestType |
| brequest | SETUP data, byte 1, bRequest |
| dpdmvalue | State D+ and D- lines will be forced into by the DPDMDRIVE task. The DPDMNODRIVE task reverts the control of the lines to MAC IP (no forcing). |
| dtoggle | Data toggle control and status |
| enable | Enable USB |
| epdatastatus | Provides information on which endpoint(s) an acknowledged data transfer has occurred (EPDATA event) |
| epin | Register block Unspecified |
| epinen | Endpoint IN enable |
| epout | Register block Unspecified |
| epouten | Endpoint OUT enable |
| epstall | STALL endpoints |
| epstatus | Provides information on which endpoint’s EasyDMA registers have been captured |
| eventcause | Details on what caused the USBEVENT event |
| events_endepin | Description collection: The whole EPIN[n] buffer has been consumed. The buffer can be accessed safely by software. |
| events_endepout | Description collection: The whole EPOUT[n] buffer has been consumed. The buffer can be accessed safely by software. |
| events_endisoin | The whole ISOIN buffer has been consumed. The buffer can be accessed safely by software. |
| events_endisoout | The whole ISOOUT buffer has been consumed. The buffer can be accessed safely by software. |
| events_ep0datadone | An acknowledged data transfer has taken place on the control endpoint |
| events_ep0setup | A valid SETUP token has been received (and acknowledged) on the control endpoint |
| events_epdata | A data transfer has occurred on a data endpoint, indicated by the EPDATASTATUS register |
| events_sof | Signals that a SOF (start of frame) condition has been detected on USB lines |
| events_started | Confirms that the EPIN[n].PTR and EPIN[n].MAXCNT, or EPOUT[n].PTR and EPOUT[n].MAXCNT registers have been captured on all endpoints reported in the EPSTATUS register |
| events_usbevent | An event or an error not covered by specific events has occurred. Check EVENTCAUSE register to find the cause. |
| events_usbreset | Signals that a USB reset condition has been detected on USB lines |
| framecntr | Returns the current value of the start of frame counter |
| halted | Register block Unspecified |
| inten | Enable or disable interrupt |
| intenclr | Disable interrupt |
| intenset | Enable interrupt |
| isoin | Register block Unspecified |
| isoinconfig | Controls the response of the ISO IN endpoint to an IN token when no data is ready to be sent |
| isoout | Register block Unspecified |
| isosplit | Controls the split of ISO buffers |
| lowpower | Controls USBD peripheral low power mode during USB suspend |
| shorts | Shortcuts between local events and tasks |
| size | Register block Unspecified |
| tasks_dpdmdrive | Forces D+ and D- lines into the state defined in the DPDMVALUE register |
| tasks_dpdmnodrive | Stops forcing D+ and D- lines into any state (USB engine takes control) |
| tasks_ep0rcvout | Allows OUT data stage on control endpoint 0 |
| tasks_ep0stall | Stalls data and status stage on control endpoint 0 |
| tasks_ep0status | Allows status stage on control endpoint 0 |
| tasks_startepin | Description collection: Captures the EPIN[n].PTR and EPIN[n].MAXCNT registers values, and enables endpoint IN n to respond to traffic from host |
| tasks_startepout | Description collection: Captures the EPOUT[n].PTR and EPOUT[n].MAXCNT registers values, and enables endpoint n to respond to traffic from host |
| tasks_startisoin | Captures the ISOIN.PTR and ISOIN.MAXCNT registers values, and enables sending data on ISO endpoint |
| tasks_startisoout | Captures the ISOOUT.PTR and ISOOUT.MAXCNT registers values, and enables receiving of data on ISO endpoint |
| usbaddr | Device USB address |
| usbpullup | Control of the USB pull-up |
| windexh | SETUP data, byte 5, MSB of wIndex |
| windexl | SETUP data, byte 4, LSB of wIndex |
| wlengthh | SETUP data, byte 7, MSB of wLength |
| wlengthl | SETUP data, byte 6, LSB of wLength |
| wvalueh | SETUP data, byte 3, MSB of wValue |
| wvaluel | SETUP data, byte 2, LSB of wValue |
Structs
| EPIN | Register block |
| EPOUT | Register block |
| HALTED | Register block |
| ISOIN | Register block |
| ISOOUT | Register block |
| RegisterBlock | Register block |
| SIZE | Register block |
Type Definitions
| BMREQUESTTYPE | SETUP data, byte 0, bmRequestType |
| BREQUEST | SETUP data, byte 1, bRequest |
| DPDMVALUE | State D+ and D- lines will be forced into by the DPDMDRIVE task. The DPDMNODRIVE task reverts the control of the lines to MAC IP (no forcing). |
| DTOGGLE | Data toggle control and status |
| ENABLE | Enable USB |
| EPDATASTATUS | Provides information on which endpoint(s) an acknowledged data transfer has occurred (EPDATA event) |
| EPINEN | Endpoint IN enable |
| EPOUTEN | Endpoint OUT enable |
| EPSTALL | STALL endpoints |
| EPSTATUS | Provides information on which endpoint’s EasyDMA registers have been captured |
| EVENTCAUSE | Details on what caused the USBEVENT event |
| EVENTS_ENDEPIN | Description collection: The whole EPIN[n] buffer has been consumed. The buffer can be accessed safely by software. |
| EVENTS_ENDEPOUT | Description collection: The whole EPOUT[n] buffer has been consumed. The buffer can be accessed safely by software. |
| EVENTS_ENDISOIN | The whole ISOIN buffer has been consumed. The buffer can be accessed safely by software. |
| EVENTS_ENDISOOUT | The whole ISOOUT buffer has been consumed. The buffer can be accessed safely by software. |
| EVENTS_EP0DATADONE | An acknowledged data transfer has taken place on the control endpoint |
| EVENTS_EP0SETUP | A valid SETUP token has been received (and acknowledged) on the control endpoint |
| EVENTS_EPDATA | A data transfer has occurred on a data endpoint, indicated by the EPDATASTATUS register |
| EVENTS_SOF | Signals that a SOF (start of frame) condition has been detected on USB lines |
| EVENTS_STARTED | Confirms that the EPIN[n].PTR and EPIN[n].MAXCNT, or EPOUT[n].PTR and EPOUT[n].MAXCNT registers have been captured on all endpoints reported in the EPSTATUS register |
| EVENTS_USBEVENT | An event or an error not covered by specific events has occurred. Check EVENTCAUSE register to find the cause. |
| EVENTS_USBRESET | Signals that a USB reset condition has been detected on USB lines |
| FRAMECNTR | Returns the current value of the start of frame counter |
| INTEN | Enable or disable interrupt |
| INTENCLR | Disable interrupt |
| INTENSET | Enable interrupt |
| ISOINCONFIG | Controls the response of the ISO IN endpoint to an IN token when no data is ready to be sent |
| ISOSPLIT | Controls the split of ISO buffers |
| LOWPOWER | Controls USBD peripheral low power mode during USB suspend |
| SHORTS | Shortcuts between local events and tasks |
| TASKS_DPDMDRIVE | Forces D+ and D- lines into the state defined in the DPDMVALUE register |
| TASKS_DPDMNODRIVE | Stops forcing D+ and D- lines into any state (USB engine takes control) |
| TASKS_EP0RCVOUT | Allows OUT data stage on control endpoint 0 |
| TASKS_EP0STALL | Stalls data and status stage on control endpoint 0 |
| TASKS_EP0STATUS | Allows status stage on control endpoint 0 |
| TASKS_STARTEPIN | Description collection: Captures the EPIN[n].PTR and EPIN[n].MAXCNT registers values, and enables endpoint IN n to respond to traffic from host |
| TASKS_STARTEPOUT | Description collection: Captures the EPOUT[n].PTR and EPOUT[n].MAXCNT registers values, and enables endpoint n to respond to traffic from host |
| TASKS_STARTISOIN | Captures the ISOIN.PTR and ISOIN.MAXCNT registers values, and enables sending data on ISO endpoint |
| TASKS_STARTISOOUT | Captures the ISOOUT.PTR and ISOOUT.MAXCNT registers values, and enables receiving of data on ISO endpoint |
| USBADDR | Device USB address |
| USBPULLUP | Control of the USB pull-up |
| WINDEXH | SETUP data, byte 5, MSB of wIndex |
| WINDEXL | SETUP data, byte 4, LSB of wIndex |
| WLENGTHH | SETUP data, byte 7, MSB of wLength |
| WLENGTHL | SETUP data, byte 6, LSB of wLength |
| WVALUEH | SETUP data, byte 3, MSB of wValue |
| WVALUEL | SETUP data, byte 2, LSB of wValue |