Module microbit::hal::pac::egu0 [−]
Event generator unit 0
Modules
| events_triggered | Description collection: Event number n generated by triggering the corresponding TRIGGER[n] task |
| inten | Enable or disable interrupt |
| intenclr | Disable interrupt |
| intenset | Enable interrupt |
| tasks_trigger | Description collection: Trigger n for triggering the corresponding TRIGGERED[n] event |
Structs
| RegisterBlock | Register block |
Type Definitions
| EVENTS_TRIGGERED | Description collection: Event number n generated by triggering the corresponding TRIGGER[n] task |
| INTEN | Enable or disable interrupt |
| INTENCLR | Disable interrupt |
| INTENSET | Enable interrupt |
| TASKS_TRIGGER | Description collection: Trigger n for triggering the corresponding TRIGGERED[n] event |