Readable

Trait Readable 

pub trait Readable: RegisterSpec {
    type Reader: From<R<Self>> + Deref<Target = R<Self>>;
}
Trait implemented by readable registers to enable the read method.

Registers marked with Writable can be also modify’ed.

Required Associated Types

type Reader: From<R<Self>> + Deref<Target = R<Self>>

Result from a call to read and argument to modify.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Readable for ADDRPTR_SPEC

read() method returns addrptr::R reader structure

Source

impl Readable for microbit::hal::pac::aar::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for microbit::hal::pac::aar::events_end::EVENTS_END_SPEC

read() method returns events_end::R reader structure

Source

impl Readable for EVENTS_NOTRESOLVED_SPEC

read() method returns events_notresolved::R reader structure

Source

impl Readable for EVENTS_RESOLVED_SPEC

read() method returns events_resolved::R reader structure

Source

impl Readable for microbit::hal::pac::aar::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::aar::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for IRKPTR_SPEC

read() method returns irkptr::R reader structure

Source

impl Readable for NIRK_SPEC

read() method returns nirk::R reader structure

Source

impl Readable for microbit::hal::pac::aar::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for microbit::hal::pac::aar::scratchptr::SCRATCHPTR_SPEC

read() method returns scratchptr::R reader structure

Source

impl Readable for microbit::hal::pac::aar::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for BUSY_SPEC

read() method returns busy::R reader structure

Source

impl Readable for microbit::hal::pac::adc::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for microbit::hal::pac::adc::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for microbit::hal::pac::adc::events_end::EVENTS_END_SPEC

read() method returns events_end::R reader structure

Source

impl Readable for microbit::hal::pac::adc::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::adc::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::adc::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for microbit::hal::pac::adc::result::RESULT_SPEC

read() method returns result::R reader structure

Source

impl Readable for CNFPTR_SPEC

read() method returns cnfptr::R reader structure

Source

impl Readable for microbit::hal::pac::ccm::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for EVENTS_ENDCRYPT_SPEC

read() method returns events_endcrypt::R reader structure

Source

impl Readable for EVENTS_ENDKSGEN_SPEC

read() method returns events_endksgen::R reader structure

Source

impl Readable for microbit::hal::pac::ccm::events_error::EVENTS_ERROR_SPEC

read() method returns events_error::R reader structure

Source

impl Readable for INPTR_SPEC

read() method returns inptr::R reader structure

Source

impl Readable for microbit::hal::pac::ccm::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::ccm::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for MICSTATUS_SPEC

read() method returns micstatus::R reader structure

Source

impl Readable for microbit::hal::pac::ccm::mode::MODE_SPEC

read() method returns mode::R reader structure

Source

impl Readable for OUTPTR_SPEC

read() method returns outptr::R reader structure

Source

impl Readable for microbit::hal::pac::ccm::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for microbit::hal::pac::ccm::scratchptr::SCRATCHPTR_SPEC

read() method returns scratchptr::R reader structure

Source

impl Readable for microbit::hal::pac::ccm::shorts::SHORTS_SPEC

read() method returns shorts::R reader structure

Source

impl Readable for CTIV_SPEC

read() method returns ctiv::R reader structure

Source

impl Readable for EVENTS_CTTO_SPEC

read() method returns events_ctto::R reader structure

Source

impl Readable for EVENTS_DONE_SPEC

read() method returns events_done::R reader structure

Source

impl Readable for EVENTS_HFCLKSTARTED_SPEC

read() method returns events_hfclkstarted::R reader structure

Source

impl Readable for EVENTS_LFCLKSTARTED_SPEC

read() method returns events_lfclkstarted::R reader structure

Source

impl Readable for HFCLKRUN_SPEC

read() method returns hfclkrun::R reader structure

Source

impl Readable for HFCLKSTAT_SPEC

read() method returns hfclkstat::R reader structure

Source

impl Readable for microbit::hal::pac::clock::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::clock::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for LFCLKRUN_SPEC

read() method returns lfclkrun::R reader structure

Source

impl Readable for LFCLKSRC_SPEC

read() method returns lfclksrc::R reader structure

Source

impl Readable for LFCLKSRCCOPY_SPEC

read() method returns lfclksrccopy::R reader structure

Source

impl Readable for LFCLKSTAT_SPEC

read() method returns lfclkstat::R reader structure

Source

impl Readable for microbit::hal::pac::clock::xtalfreq::XTALFREQ_SPEC

read() method returns xtalfreq::R reader structure

Source

impl Readable for ECBDATAPTR_SPEC

read() method returns ecbdataptr::R reader structure

Source

impl Readable for EVENTS_ENDECB_SPEC

read() method returns events_endecb::R reader structure

Source

impl Readable for EVENTS_ERRORECB_SPEC

read() method returns events_errorecb::R reader structure

Source

impl Readable for microbit::hal::pac::ecb::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::ecb::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::ecb::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for BLE_1MBIT_SPEC

read() method returns ble_1mbit::R reader structure

Source

impl Readable for microbit::hal::pac::ficr::clenr0::CLENR0_SPEC

read() method returns clenr0::R reader structure

Source

impl Readable for CODEPAGESIZE_SPEC

read() method returns codepagesize::R reader structure

Source

impl Readable for CODESIZE_SPEC

read() method returns codesize::R reader structure

Source

impl Readable for CONFIGID_SPEC

read() method returns configid::R reader structure

Source

impl Readable for DEVICEADDR_SPEC

read() method returns deviceaddr::R reader structure

Source

impl Readable for DEVICEADDRTYPE_SPEC

read() method returns deviceaddrtype::R reader structure

Source

impl Readable for DEVICEID_SPEC

read() method returns deviceid::R reader structure

Source

impl Readable for ER_SPEC

read() method returns er::R reader structure

Source

impl Readable for IR_SPEC

read() method returns ir::R reader structure

Source

impl Readable for NRF_1MBIT_SPEC

read() method returns nrf_1mbit::R reader structure

Source

impl Readable for NUMRAMBLOCK_SPEC

read() method returns numramblock::R reader structure

Source

impl Readable for OVERRIDEEN_SPEC

read() method returns overrideen::R reader structure

Source

impl Readable for PPFC_SPEC

read() method returns ppfc::R reader structure

Source

impl Readable for SIZERAMBLOCK_SPEC

read() method returns sizeramblock::R reader structure

Source

impl Readable for SIZERAMBLOCKS_SPEC

read() method returns sizeramblocks::R reader structure

Source

impl Readable for DIR_SPEC

read() method returns dir::R reader structure

Source

impl Readable for DIRCLR_SPEC

read() method returns dirclr::R reader structure

Source

impl Readable for DIRSET_SPEC

read() method returns dirset::R reader structure

Source

impl Readable for IN_SPEC

read() method returns in_::R reader structure

Source

impl Readable for OUT_SPEC

read() method returns out::R reader structure

Source

impl Readable for OUTCLR_SPEC

read() method returns outclr::R reader structure

Source

impl Readable for OUTSET_SPEC

read() method returns outset::R reader structure

Source

impl Readable for PIN_CNF_SPEC

read() method returns pin_cnf::R reader structure

Source

impl Readable for microbit::hal::pac::gpiote::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for EVENTS_IN_SPEC

read() method returns events_in::R reader structure

Source

impl Readable for EVENTS_PORT_SPEC

read() method returns events_port::R reader structure

Source

impl Readable for microbit::hal::pac::gpiote::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::gpiote::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::gpiote::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for ANADETECT_SPEC

read() method returns anadetect::R reader structure

Source

impl Readable for microbit::hal::pac::lpcomp::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for EVENTS_CROSS_SPEC

read() method returns events_cross::R reader structure

Source

impl Readable for EVENTS_DOWN_SPEC

read() method returns events_down::R reader structure

Source

impl Readable for microbit::hal::pac::lpcomp::events_ready::EVENTS_READY_SPEC

read() method returns events_ready::R reader structure

Source

impl Readable for EVENTS_UP_SPEC

read() method returns events_up::R reader structure

Source

impl Readable for EXTREFSEL_SPEC

read() method returns extrefsel::R reader structure

Source

impl Readable for microbit::hal::pac::lpcomp::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::lpcomp::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::lpcomp::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for PSEL_SPEC

read() method returns psel::R reader structure

Source

impl Readable for REFSEL_SPEC

read() method returns refsel::R reader structure

Source

impl Readable for microbit::hal::pac::lpcomp::result::RESULT_SPEC

read() method returns result::R reader structure

Source

impl Readable for microbit::hal::pac::lpcomp::shorts::SHORTS_SPEC

read() method returns shorts::R reader structure

Source

impl Readable for microbit::hal::pac::nvmc::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for ERASEALL_SPEC

read() method returns eraseall::R reader structure

Source

impl Readable for ERASEPAGE_SPEC

read() method returns erasepage::R reader structure

Source

impl Readable for ERASEPCR0_SPEC

read() method returns erasepcr0::R reader structure

Source

impl Readable for ERASEPCR1_SPEC

read() method returns erasepcr1::R reader structure

Source

impl Readable for ERASEUICR_SPEC

read() method returns eraseuicr::R reader structure

Source

impl Readable for READY_SPEC

read() method returns ready::R reader structure

Source

impl Readable for DCDCEN_SPEC

read() method returns dcdcen::R reader structure

Source

impl Readable for DCDCFORCE_SPEC

read() method returns dcdcforce::R reader structure

Source

impl Readable for EVENTS_POFWARN_SPEC

read() method returns events_pofwarn::R reader structure

Source

impl Readable for GPREGRET_SPEC

read() method returns gpregret::R reader structure

Source

impl Readable for microbit::hal::pac::power::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::power::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for POFCON_SPEC

read() method returns pofcon::R reader structure

Source

impl Readable for RAMON_SPEC

read() method returns ramon::R reader structure

Source

impl Readable for RAMONB_SPEC

read() method returns ramonb::R reader structure

Source

impl Readable for RAMSTATUS_SPEC

read() method returns ramstatus::R reader structure

Source

impl Readable for RESET_SPEC

read() method returns reset::R reader structure

Source

impl Readable for RESETREAS_SPEC

read() method returns resetreas::R reader structure

Source

impl Readable for EEP_SPEC

read() method returns eep::R reader structure

Source

impl Readable for TEP_SPEC

read() method returns tep::R reader structure

Source

impl Readable for CHEN_SPEC

read() method returns chen::R reader structure

Source

impl Readable for CHENCLR_SPEC

read() method returns chenclr::R reader structure

Source

impl Readable for CHENSET_SPEC

read() method returns chenset::R reader structure

Source

impl Readable for CHG_SPEC

read() method returns chg::R reader structure

Source

impl Readable for ACC_SPEC

read() method returns acc::R reader structure

Source

impl Readable for ACCDBL_SPEC

read() method returns accdbl::R reader structure

Source

impl Readable for ACCDBLREAD_SPEC

read() method returns accdblread::R reader structure

Source

impl Readable for ACCREAD_SPEC

read() method returns accread::R reader structure

Source

impl Readable for DBFEN_SPEC

read() method returns dbfen::R reader structure

Source

impl Readable for microbit::hal::pac::qdec::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for EVENTS_ACCOF_SPEC

read() method returns events_accof::R reader structure

Source

impl Readable for EVENTS_REPORTRDY_SPEC

read() method returns events_reportrdy::R reader structure

Source

impl Readable for EVENTS_SAMPLERDY_SPEC

read() method returns events_samplerdy::R reader structure

Source

impl Readable for microbit::hal::pac::qdec::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::qdec::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for LEDPOL_SPEC

read() method returns ledpol::R reader structure

Source

impl Readable for LEDPRE_SPEC

read() method returns ledpre::R reader structure

Source

impl Readable for microbit::hal::pac::qdec::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for PSELA_SPEC

read() method returns psela::R reader structure

Source

impl Readable for PSELB_SPEC

read() method returns pselb::R reader structure

Source

impl Readable for PSELLED_SPEC

read() method returns pselled::R reader structure

Source

impl Readable for REPORTPER_SPEC

read() method returns reportper::R reader structure

Source

impl Readable for SAMPLE_SPEC

read() method returns sample::R reader structure

Source

impl Readable for SAMPLEPER_SPEC

read() method returns sampleper::R reader structure

Source

impl Readable for microbit::hal::pac::qdec::shorts::SHORTS_SPEC

read() method returns shorts::R reader structure

Source

impl Readable for BASE0_SPEC

read() method returns base0::R reader structure

Source

impl Readable for BASE1_SPEC

read() method returns base1::R reader structure

Source

impl Readable for BCC_SPEC

read() method returns bcc::R reader structure

Source

impl Readable for CRCCNF_SPEC

read() method returns crccnf::R reader structure

Source

impl Readable for CRCINIT_SPEC

read() method returns crcinit::R reader structure

Source

impl Readable for CRCPOLY_SPEC

read() method returns crcpoly::R reader structure

Source

impl Readable for CRCSTATUS_SPEC

read() method returns crcstatus::R reader structure

Source

impl Readable for DAB_SPEC

read() method returns dab::R reader structure

Source

impl Readable for DACNF_SPEC

read() method returns dacnf::R reader structure

Source

impl Readable for DAI_SPEC

read() method returns dai::R reader structure

Source

impl Readable for DAP_SPEC

read() method returns dap::R reader structure

Source

impl Readable for DATAWHITEIV_SPEC

read() method returns datawhiteiv::R reader structure

Source

impl Readable for EVENTS_ADDRESS_SPEC

read() method returns events_address::R reader structure

Source

impl Readable for EVENTS_BCMATCH_SPEC

read() method returns events_bcmatch::R reader structure

Source

impl Readable for EVENTS_DEVMATCH_SPEC

read() method returns events_devmatch::R reader structure

Source

impl Readable for EVENTS_DEVMISS_SPEC

read() method returns events_devmiss::R reader structure

Source

impl Readable for EVENTS_DISABLED_SPEC

read() method returns events_disabled::R reader structure

Source

impl Readable for microbit::hal::pac::radio::events_end::EVENTS_END_SPEC

read() method returns events_end::R reader structure

Source

impl Readable for EVENTS_PAYLOAD_SPEC

read() method returns events_payload::R reader structure

Source

impl Readable for microbit::hal::pac::radio::events_ready::EVENTS_READY_SPEC

read() method returns events_ready::R reader structure

Source

impl Readable for EVENTS_RSSIEND_SPEC

read() method returns events_rssiend::R reader structure

Source

impl Readable for microbit::hal::pac::radio::frequency::FREQUENCY_SPEC

read() method returns frequency::R reader structure

Source

impl Readable for microbit::hal::pac::radio::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::radio::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::radio::mode::MODE_SPEC

read() method returns mode::R reader structure

Source

impl Readable for OVERRIDE0_SPEC

read() method returns override0::R reader structure

Source

impl Readable for OVERRIDE1_SPEC

read() method returns override1::R reader structure

Source

impl Readable for OVERRIDE2_SPEC

read() method returns override2::R reader structure

Source

impl Readable for OVERRIDE3_SPEC

read() method returns override3::R reader structure

Source

impl Readable for OVERRIDE4_SPEC

read() method returns override4::R reader structure

Source

impl Readable for PACKETPTR_SPEC

read() method returns packetptr::R reader structure

Source

impl Readable for PCNF0_SPEC

read() method returns pcnf0::R reader structure

Source

impl Readable for PCNF1_SPEC

read() method returns pcnf1::R reader structure

Source

impl Readable for microbit::hal::pac::radio::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for PREFIX0_SPEC

read() method returns prefix0::R reader structure

Source

impl Readable for PREFIX1_SPEC

read() method returns prefix1::R reader structure

Source

impl Readable for RSSISAMPLE_SPEC

read() method returns rssisample::R reader structure

Source

impl Readable for RXADDRESSES_SPEC

read() method returns rxaddresses::R reader structure

Source

impl Readable for RXCRC_SPEC

read() method returns rxcrc::R reader structure

Source

impl Readable for RXMATCH_SPEC

read() method returns rxmatch::R reader structure

Source

impl Readable for microbit::hal::pac::radio::shorts::SHORTS_SPEC

read() method returns shorts::R reader structure

Source

impl Readable for STATE_SPEC

read() method returns state::R reader structure

Source

impl Readable for TEST_SPEC

read() method returns test::R reader structure

Source

impl Readable for TIFS_SPEC

read() method returns tifs::R reader structure

Source

impl Readable for TXADDRESS_SPEC

read() method returns txaddress::R reader structure

Source

impl Readable for TXPOWER_SPEC

read() method returns txpower::R reader structure

Source

impl Readable for microbit::hal::pac::rng::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for EVENTS_VALRDY_SPEC

read() method returns events_valrdy::R reader structure

Source

impl Readable for microbit::hal::pac::rng::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::rng::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::rng::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for microbit::hal::pac::rng::shorts::SHORTS_SPEC

read() method returns shorts::R reader structure

Source

impl Readable for VALUE_SPEC

read() method returns value::R reader structure

Source

impl Readable for microbit::hal::pac::rtc0::cc::CC_SPEC

read() method returns cc::R reader structure

Source

impl Readable for COUNTER_SPEC

read() method returns counter::R reader structure

Source

impl Readable for microbit::hal::pac::rtc0::events_compare::EVENTS_COMPARE_SPEC

read() method returns events_compare::R reader structure

Source

impl Readable for EVENTS_OVRFLW_SPEC

read() method returns events_ovrflw::R reader structure

Source

impl Readable for EVENTS_TICK_SPEC

read() method returns events_tick::R reader structure

Source

impl Readable for EVTEN_SPEC

read() method returns evten::R reader structure

Source

impl Readable for EVTENCLR_SPEC

read() method returns evtenclr::R reader structure

Source

impl Readable for EVTENSET_SPEC

read() method returns evtenset::R reader structure

Source

impl Readable for microbit::hal::pac::rtc0::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::rtc0::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::rtc0::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for microbit::hal::pac::rtc0::prescaler::PRESCALER_SPEC

read() method returns prescaler::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::events_ready::EVENTS_READY_SPEC

read() method returns events_ready::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::frequency::FREQUENCY_SPEC

read() method returns frequency::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::pselmiso::PSELMISO_SPEC

read() method returns pselmiso::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::pselmosi::PSELMOSI_SPEC

read() method returns pselmosi::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::pselsck::PSELSCK_SPEC

read() method returns pselsck::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::rxd::RXD_SPEC

read() method returns rxd::R reader structure

Source

impl Readable for microbit::hal::pac::spi0::txd::TXD_SPEC

read() method returns txd::R reader structure

Source

impl Readable for AMOUNTRX_SPEC

read() method returns amountrx::R reader structure

Source

impl Readable for AMOUNTTX_SPEC

read() method returns amounttx::R reader structure

Source

impl Readable for microbit::hal::pac::spis1::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for DEF_SPEC

read() method returns def::R reader structure

Source

impl Readable for microbit::hal::pac::spis1::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for EVENTS_ACQUIRED_SPEC

read() method returns events_acquired::R reader structure

Source

impl Readable for microbit::hal::pac::spis1::events_end::EVENTS_END_SPEC

read() method returns events_end::R reader structure

Source

impl Readable for EVENTS_ENDRX_SPEC

read() method returns events_endrx::R reader structure

Source

impl Readable for microbit::hal::pac::spis1::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::spis1::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for MAXRX_SPEC

read() method returns maxrx::R reader structure

Source

impl Readable for MAXTX_SPEC

read() method returns maxtx::R reader structure

Source

impl Readable for ORC_SPEC

read() method returns orc::R reader structure

Source

impl Readable for microbit::hal::pac::spis1::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for PSELCSN_SPEC

read() method returns pselcsn::R reader structure

Source

impl Readable for microbit::hal::pac::spis1::pselmiso::PSELMISO_SPEC

read() method returns pselmiso::R reader structure

Source

impl Readable for microbit::hal::pac::spis1::pselmosi::PSELMOSI_SPEC

read() method returns pselmosi::R reader structure

Source

impl Readable for microbit::hal::pac::spis1::pselsck::PSELSCK_SPEC

read() method returns pselsck::R reader structure

Source

impl Readable for RXDPTR_SPEC

read() method returns rxdptr::R reader structure

Source

impl Readable for SEMSTAT_SPEC

read() method returns semstat::R reader structure

Source

impl Readable for microbit::hal::pac::spis1::shorts::SHORTS_SPEC

read() method returns shorts::R reader structure

Source

impl Readable for microbit::hal::pac::spis1::status::STATUS_SPEC

read() method returns status::R reader structure

Source

impl Readable for TXDPTR_SPEC

read() method returns txdptr::R reader structure

Source

impl Readable for UNUSED_SPEC

read() method returns unused::R reader structure

Source

impl Readable for EVENTS_DATARDY_SPEC

read() method returns events_datardy::R reader structure

Source

impl Readable for microbit::hal::pac::temp::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::temp::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::temp::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for TEMP_SPEC

read() method returns temp::R reader structure

Source

impl Readable for BITMODE_SPEC

read() method returns bitmode::R reader structure

Source

impl Readable for microbit::hal::pac::timer0::cc::CC_SPEC

read() method returns cc::R reader structure

Source

impl Readable for microbit::hal::pac::timer0::events_compare::EVENTS_COMPARE_SPEC

read() method returns events_compare::R reader structure

Source

impl Readable for microbit::hal::pac::timer0::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::timer0::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::timer0::mode::MODE_SPEC

read() method returns mode::R reader structure

Source

impl Readable for microbit::hal::pac::timer0::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for microbit::hal::pac::timer0::prescaler::PRESCALER_SPEC

read() method returns prescaler::R reader structure

Source

impl Readable for microbit::hal::pac::timer0::shorts::SHORTS_SPEC

read() method returns shorts::R reader structure

Source

impl Readable for ADDRESS_SPEC

read() method returns address::R reader structure

Source

impl Readable for microbit::hal::pac::twi0::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for microbit::hal::pac::twi0::errorsrc::ERRORSRC_SPEC

read() method returns errorsrc::R reader structure

Source

impl Readable for EVENTS_BB_SPEC

read() method returns events_bb::R reader structure

Source

impl Readable for microbit::hal::pac::twi0::events_error::EVENTS_ERROR_SPEC

read() method returns events_error::R reader structure

Source

impl Readable for EVENTS_RXDREADY_SPEC

read() method returns events_rxdready::R reader structure

Source

impl Readable for EVENTS_STOPPED_SPEC

read() method returns events_stopped::R reader structure

Source

impl Readable for EVENTS_SUSPENDED_SPEC

read() method returns events_suspended::R reader structure

Source

impl Readable for EVENTS_TXDSENT_SPEC

read() method returns events_txdsent::R reader structure

Source

impl Readable for microbit::hal::pac::twi0::frequency::FREQUENCY_SPEC

read() method returns frequency::R reader structure

Source

impl Readable for microbit::hal::pac::twi0::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::twi0::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::twi0::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for PSELSCL_SPEC

read() method returns pselscl::R reader structure

Source

impl Readable for PSELSDA_SPEC

read() method returns pselsda::R reader structure

Source

impl Readable for microbit::hal::pac::twi0::rxd::RXD_SPEC

read() method returns rxd::R reader structure

Source

impl Readable for microbit::hal::pac::twi0::shorts::SHORTS_SPEC

read() method returns shorts::R reader structure

Source

impl Readable for microbit::hal::pac::twi0::txd::TXD_SPEC

read() method returns txd::R reader structure

Source

impl Readable for BAUDRATE_SPEC

read() method returns baudrate::R reader structure

Source

impl Readable for microbit::hal::pac::uart0::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for microbit::hal::pac::uart0::enable::ENABLE_SPEC

read() method returns enable::R reader structure

Source

impl Readable for microbit::hal::pac::uart0::errorsrc::ERRORSRC_SPEC

read() method returns errorsrc::R reader structure

Source

impl Readable for EVENTS_CTS_SPEC

read() method returns events_cts::R reader structure

Source

impl Readable for microbit::hal::pac::uart0::events_error::EVENTS_ERROR_SPEC

read() method returns events_error::R reader structure

Source

impl Readable for EVENTS_NCTS_SPEC

read() method returns events_ncts::R reader structure

Source

impl Readable for EVENTS_RXDRDY_SPEC

read() method returns events_rxdrdy::R reader structure

Source

impl Readable for EVENTS_RXTO_SPEC

read() method returns events_rxto::R reader structure

Source

impl Readable for EVENTS_TXDRDY_SPEC

read() method returns events_txdrdy::R reader structure

Source

impl Readable for microbit::hal::pac::uart0::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::uart0::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::uart0::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for PSELCTS_SPEC

read() method returns pselcts::R reader structure

Source

impl Readable for PSELRTS_SPEC

read() method returns pselrts::R reader structure

Source

impl Readable for PSELRXD_SPEC

read() method returns pselrxd::R reader structure

Source

impl Readable for PSELTXD_SPEC

read() method returns pseltxd::R reader structure

Source

impl Readable for microbit::hal::pac::uart0::rxd::RXD_SPEC

read() method returns rxd::R reader structure

Source

impl Readable for microbit::hal::pac::uart0::shorts::SHORTS_SPEC

read() method returns shorts::R reader structure

Source

impl Readable for BOOTLOADERADDR_SPEC

read() method returns bootloaderaddr::R reader structure

Source

impl Readable for microbit::hal::pac::uicr::clenr0::CLENR0_SPEC

read() method returns clenr0::R reader structure

Source

impl Readable for CUSTOMER_SPEC

read() method returns customer::R reader structure

Source

impl Readable for FWID_SPEC

read() method returns fwid::R reader structure

Source

impl Readable for NRFFW_SPEC

read() method returns nrffw::R reader structure

Source

impl Readable for NRFHW_SPEC

read() method returns nrfhw::R reader structure

Source

impl Readable for RBPCONF_SPEC

read() method returns rbpconf::R reader structure

Source

impl Readable for microbit::hal::pac::uicr::xtalfreq::XTALFREQ_SPEC

read() method returns xtalfreq::R reader structure

Source

impl Readable for microbit::hal::pac::wdt::config::CONFIG_SPEC

read() method returns config::R reader structure

Source

impl Readable for CRV_SPEC

read() method returns crv::R reader structure

Source

impl Readable for EVENTS_TIMEOUT_SPEC

read() method returns events_timeout::R reader structure

Source

impl Readable for microbit::hal::pac::wdt::intenclr::INTENCLR_SPEC

read() method returns intenclr::R reader structure

Source

impl Readable for microbit::hal::pac::wdt::intenset::INTENSET_SPEC

read() method returns intenset::R reader structure

Source

impl Readable for microbit::hal::pac::wdt::power::POWER_SPEC

read() method returns power::R reader structure

Source

impl Readable for REQSTATUS_SPEC

read() method returns reqstatus::R reader structure

Source

impl Readable for RREN_SPEC

read() method returns rren::R reader structure

Source

impl Readable for RUNSTATUS_SPEC

read() method returns runstatus::R reader structure