#[repr(C)]pub struct RegisterBlock {Show 14 fields
pub tasks_start: Reg<TASKS_START_SPEC>,
pub tasks_stop: Reg<TASKS_STOP_SPEC>,
pub events_rxptrupd: Reg<EVENTS_RXPTRUPD_SPEC>,
pub events_stopped: Reg<EVENTS_STOPPED_SPEC>,
pub events_txptrupd: Reg<EVENTS_TXPTRUPD_SPEC>,
pub inten: Reg<INTEN_SPEC>,
pub intenset: Reg<INTENSET_SPEC>,
pub intenclr: Reg<INTENCLR_SPEC>,
pub enable: Reg<ENABLE_SPEC>,
pub config: CONFIG,
pub rxd: RXD,
pub txd: TXD,
pub rxtxd: RXTXD,
pub psel: PSEL,
/* private fields */
}Expand description
Register block
Fields
tasks_start: Reg<TASKS_START_SPEC>0x00 - Starts continuous I2S transfer. Also starts MCK generator when this is enabled.
tasks_stop: Reg<TASKS_STOP_SPEC>0x04 - Stops I2S transfer. Also stops MCK generator. Triggering this task will cause the STOPPED event to be generated.
events_rxptrupd: Reg<EVENTS_RXPTRUPD_SPEC>0x104 - The RXD.PTR register has been copied to internal double-buffers. When the I2S module is started and RX is enabled, this event will be generated for every RXTXD.MAXCNT words that are received on the SDIN pin.
events_stopped: Reg<EVENTS_STOPPED_SPEC>0x108 - I2S transfer stopped.
events_txptrupd: Reg<EVENTS_TXPTRUPD_SPEC>0x114 - The TDX.PTR register has been copied to internal double-buffers. When the I2S module is started and TX is enabled, this event will be generated for every RXTXD.MAXCNT words that are sent on the SDOUT pin.
inten: Reg<INTEN_SPEC>0x300 - Enable or disable interrupt
intenset: Reg<INTENSET_SPEC>0x304 - Enable interrupt
intenclr: Reg<INTENCLR_SPEC>0x308 - Disable interrupt
enable: Reg<ENABLE_SPEC>0x500 - Enable I2S module.
config: CONFIG0x504..0x52c - Unspecified
rxd: RXD0x538 - Unspecified
txd: TXD0x540 - Unspecified
rxtxd: RXTXD0x550 - Unspecified
psel: PSEL0x560..0x574 - Unspecified