Struct microbit::hal::pac::i2s::RegisterBlock [−]
#[repr(C)]pub struct RegisterBlock {}Show fields
pub tasks_start: Reg<u32, _TASKS_START>, pub tasks_stop: Reg<u32, _TASKS_STOP>, pub events_rxptrupd: Reg<u32, _EVENTS_RXPTRUPD>, pub events_stopped: Reg<u32, _EVENTS_STOPPED>, pub events_txptrupd: Reg<u32, _EVENTS_TXPTRUPD>, pub inten: Reg<u32, _INTEN>, pub intenset: Reg<u32, _INTENSET>, pub intenclr: Reg<u32, _INTENCLR>, pub enable: Reg<u32, _ENABLE>, pub config: CONFIG, pub rxd: RXD, pub txd: TXD, pub rxtxd: RXTXD, pub psel: PSEL, // some fields omitted
Register block
Fields
tasks_start: Reg<u32, _TASKS_START>0x00 - Starts continuous I2S transfer. Also starts MCK generator when this is enabled.
tasks_stop: Reg<u32, _TASKS_STOP>0x04 - Stops I2S transfer. Also stops MCK generator. Triggering this task will cause the STOPPED event to be generated.
events_rxptrupd: Reg<u32, _EVENTS_RXPTRUPD>0x104 - The RXD.PTR register has been copied to internal double-buffers. When the I2S module is started and RX is enabled, this event will be generated for every RXTXD.MAXCNT words that are received on the SDIN pin.
events_stopped: Reg<u32, _EVENTS_STOPPED>0x108 - I2S transfer stopped.
events_txptrupd: Reg<u32, _EVENTS_TXPTRUPD>0x114 - The TDX.PTR register has been copied to internal double-buffers. When the I2S module is started and TX is enabled, this event will be generated for every RXTXD.MAXCNT words that are sent on the SDOUT pin.
inten: Reg<u32, _INTEN>0x300 - Enable or disable interrupt
intenset: Reg<u32, _INTENSET>0x304 - Enable interrupt
intenclr: Reg<u32, _INTENCLR>0x308 - Disable interrupt
enable: Reg<u32, _ENABLE>0x500 - Enable I2S module.
config: CONFIG0x504 - Unspecified
rxd: RXD0x538 - Unspecified
txd: TXD0x540 - Unspecified
rxtxd: RXTXD0x550 - Unspecified
psel: PSEL0x560 - Unspecified