#[repr(C)]pub struct RegisterBlock {
pub ready: Reg<READY_SPEC>,
pub readynext: Reg<READYNEXT_SPEC>,
pub config: Reg<CONFIG_SPEC>,
pub eraseall: Reg<ERASEALL_SPEC>,
pub erasepcr0: Reg<ERASEPCR0_SPEC>,
pub eraseuicr: Reg<ERASEUICR_SPEC>,
pub erasepagepartial: Reg<ERASEPAGEPARTIAL_SPEC>,
pub erasepagepartialcfg: Reg<ERASEPAGEPARTIALCFG_SPEC>,
pub icachecnf: Reg<ICACHECNF_SPEC>,
pub ihit: Reg<IHIT_SPEC>,
pub imiss: Reg<IMISS_SPEC>,
/* private fields */
}Expand description
Register block
Fields
ready: Reg<READY_SPEC>0x400 - Ready flag
readynext: Reg<READYNEXT_SPEC>0x408 - Ready flag
config: Reg<CONFIG_SPEC>0x504 - Configuration register
eraseall: Reg<ERASEALL_SPEC>0x50c - Register for erasing all non-volatile user memory
erasepcr0: Reg<ERASEPCR0_SPEC>0x510 - Deprecated register - Register for erasing a page in code area, equivalent to ERASEPAGE
eraseuicr: Reg<ERASEUICR_SPEC>0x514 - Register for erasing user information configuration registers
erasepagepartial: Reg<ERASEPAGEPARTIAL_SPEC>0x518 - Register for partial erase of a page in code area
erasepagepartialcfg: Reg<ERASEPAGEPARTIALCFG_SPEC>0x51c - Register for partial erase configuration
icachecnf: Reg<ICACHECNF_SPEC>0x540 - I-code cache configuration register
ihit: Reg<IHIT_SPEC>0x548 - I-code cache hit counter
imiss: Reg<IMISS_SPEC>0x54c - I-code cache miss counter
Implementations
impl RegisterBlock
impl RegisterBlock
pub fn erasepcr1(&self) -> &Reg<ERASEPCR1_SPEC>
pub fn erasepcr1(&self) -> &Reg<ERASEPCR1_SPEC>
0x508 - Deprecated register - Register for erasing a page in code area, equivalent to ERASEPAGE
pub fn erasepage(&self) -> &Reg<ERASEPAGE_SPEC>
pub fn erasepage(&self) -> &Reg<ERASEPAGE_SPEC>
0x508 - Register for erasing a page in code area