Struct microbit::hal::pac::nvmc::RegisterBlock[]

#[repr(C)]
pub struct RegisterBlock { pub ready: Reg<u32, _READY>, pub readynext: Reg<u32, _READYNEXT>, pub config: Reg<u32, _CONFIG>, pub eraseall: Reg<u32, _ERASEALL>, pub erasepcr0: Reg<u32, _ERASEPCR0>, pub eraseuicr: Reg<u32, _ERASEUICR>, pub erasepagepartial: Reg<u32, _ERASEPAGEPARTIAL>, pub erasepagepartialcfg: Reg<u32, _ERASEPAGEPARTIALCFG>, pub icachecnf: Reg<u32, _ICACHECNF>, pub ihit: Reg<u32, _IHIT>, pub imiss: Reg<u32, _IMISS>, // some fields omitted }
Register block

Fields

ready: Reg<u32, _READY>

0x400 - Ready flag

readynext: Reg<u32, _READYNEXT>

0x408 - Ready flag

config: Reg<u32, _CONFIG>

0x504 - Configuration register

eraseall: Reg<u32, _ERASEALL>

0x50c - Register for erasing all non-volatile user memory

erasepcr0: Reg<u32, _ERASEPCR0>

0x510 - Deprecated register - Register for erasing a page in code area, equivalent to ERASEPAGE

eraseuicr: Reg<u32, _ERASEUICR>

0x514 - Register for erasing user information configuration registers

erasepagepartial: Reg<u32, _ERASEPAGEPARTIAL>

0x518 - Register for partial erase of a page in code area

erasepagepartialcfg: Reg<u32, _ERASEPAGEPARTIALCFG>

0x51c - Register for partial erase configuration

icachecnf: Reg<u32, _ICACHECNF>

0x540 - I-code cache configuration register

ihit: Reg<u32, _IHIT>

0x548 - I-code cache hit counter

imiss: Reg<u32, _IMISS>

0x54c - I-code cache miss counter

Implementations

impl RegisterBlock

pub fn erasepcr1(&self) -> &Reg<u32, _ERASEPCR1>

0x508 - Deprecated register - Register for erasing a page in code area, equivalent to ERASEPAGE

pub fn erasepcr1_mut(&self) -> &mut Reg<u32, _ERASEPCR1>

0x508 - Deprecated register - Register for erasing a page in code area, equivalent to ERASEPAGE

pub fn erasepage(&self) -> &Reg<u32, _ERASEPAGE>

0x508 - Register for erasing a page in code area

pub fn erasepage_mut(&self) -> &mut Reg<u32, _ERASEPAGE>

0x508 - Register for erasing a page in code area