pub struct R(_);Expand description
Register POFCON reader
Implementations
impl R
impl R
pub fn threshold(&self) -> THRESHOLD_R
pub fn threshold(&self) -> THRESHOLD_R
Bits 1:4 - Power-fail comparator threshold setting. This setting applies both for normal voltage mode (supply connected to both VDD and VDDH) and high voltage mode (supply connected to VDDH only). Values 0-3 set threshold below 1.7 V and should not be used as brown out detection will be activated before power failure warning on such low voltages.
pub fn thresholdvddh(&self) -> THRESHOLDVDDH_R
pub fn thresholdvddh(&self) -> THRESHOLDVDDH_R
Bits 8:11 - Power-fail comparator threshold setting for high voltage mode (supply connected to VDDH only). This setting does not apply for normal voltage mode (supply connected to both VDD and VDDH).
Methods from Deref<Target = R<POFCON_SPEC>>
pub fn bits(&self) -> <REG as RegisterSpec>::Ux
pub fn bits(&self) -> <REG as RegisterSpec>::Ux
Reads raw bits from register.