Struct microbit::hal::Timer [−][src]
pub struct Timer<T, U = OneShot>(_, _);
Interface to a TIMER instance.
Right now, this is a very basic interface. The timer will always be hardcoded to a frequency of 1 MHz and 32 bits accuracy.
CC[0] is used for the current/most-recent delay period and CC[1] is used to grab the current value of the counter at a given instant.
Implementations
impl<T, U> Timer<T, U> where
T: Instance, [src]
impl<T, U> Timer<T, U> where
T: Instance, [src]pub const TICKS_PER_SECOND: u32[src]
pub fn into_periodic(self) -> Timer<T, Periodic>[src]
pub fn into_oneshot(self) -> Timer<T, OneShot>[src]
pub fn enable_interrupt(&mut self)[src]
pub fn enable_interrupt(&mut self)[src]Enables the interrupt for this timer.
Enables an interrupt that is fired when the timer reaches the value that
is given as an argument to start.
Note that the interrupt also has to be unmasked in the NVIC, or the handler won’t get called.
pub fn disable_interrupt(&mut self)[src]
pub fn disable_interrupt(&mut self)[src]Disables the interrupt for this timer.
Disables an interrupt that is fired when the timer reaches the value
that is given as an argument to start.
Note that the interrupt also has to be unmasked in the NVIC, or the handler won’t get called.
pub fn delay(&mut self, cycles: u32)[src]
pub fn task_start(&self) -> &Reg<u32, _TASKS_START>[src]
pub fn task_start(&self) -> &Reg<u32, _TASKS_START>[src]Returns reference to the START task endpoint for PPI.
Starts timer.
pub fn task_stop(&self) -> &Reg<u32, _TASKS_STOP>[src]
pub fn task_stop(&self) -> &Reg<u32, _TASKS_STOP>[src]Returns reference to the STOP task endpoint for PPI.
Stops timer.
pub fn task_count(&self) -> &Reg<u32, _TASKS_COUNT>[src]
pub fn task_count(&self) -> &Reg<u32, _TASKS_COUNT>[src]Returns reference to the COUNT task endpoint for PPI.
Increments timer (counter mode only).
pub fn task_clear(&self) -> &Reg<u32, _TASKS_CLEAR>[src]
pub fn task_clear(&self) -> &Reg<u32, _TASKS_CLEAR>[src]Returns reference to the CLEAR task endpoint for PPI.
Clears timer.
pub fn task_capture_cc0(&self) -> &Reg<u32, _TASKS_CAPTURE>[src]
pub fn task_capture_cc0(&self) -> &Reg<u32, _TASKS_CAPTURE>[src]Returns reference to the CC[0] CAPTURE task endpoint for PPI.
Captures timer value to the CC[0] register.
pub fn task_capture_cc1(&self) -> &Reg<u32, _TASKS_CAPTURE>[src]
pub fn task_capture_cc1(&self) -> &Reg<u32, _TASKS_CAPTURE>[src]Returns reference to the CC[1] CAPTURE task endpoint for PPI.
Captures timer value to the CC[1] register.
pub fn task_capture_cc2(&self) -> &Reg<u32, _TASKS_CAPTURE>[src]
pub fn task_capture_cc2(&self) -> &Reg<u32, _TASKS_CAPTURE>[src]Returns reference to the CC[2] CAPTURE task endpoint for PPI.
Captures timer value to the CC[2] register.
pub fn task_capture_cc3(&self) -> &Reg<u32, _TASKS_CAPTURE>[src]
pub fn task_capture_cc3(&self) -> &Reg<u32, _TASKS_CAPTURE>[src]Returns reference to the CC[3] CAPTURE task endpoint for PPI.
Captures timer value to the CC[3] register.
pub fn event_compare_cc0(&self) -> &Reg<u32, _EVENTS_COMPARE>[src]
pub fn event_compare_cc0(&self) -> &Reg<u32, _EVENTS_COMPARE>[src]Returns reference to the CC[0] COMPARE event endpoint for PPI.
Generated when the counter is incremented and then matches the value
specified in the CC[0] register.
pub fn event_compare_cc1(&self) -> &Reg<u32, _EVENTS_COMPARE>[src]
pub fn event_compare_cc1(&self) -> &Reg<u32, _EVENTS_COMPARE>[src]Returns reference to the CC[1] COMPARE event endpoint for PPI.
Generated when the counter is incremented and then matches the value
specified in the CC[1] register.
pub fn event_compare_cc2(&self) -> &Reg<u32, _EVENTS_COMPARE>[src]
pub fn event_compare_cc2(&self) -> &Reg<u32, _EVENTS_COMPARE>[src]Returns reference to the CC[2] COMPARE event endpoint for PPI.
Generated when the counter is incremented and then matches the value
specified in the CC[2] register.
pub fn event_compare_cc3(&self) -> &Reg<u32, _EVENTS_COMPARE>[src]
pub fn event_compare_cc3(&self) -> &Reg<u32, _EVENTS_COMPARE>[src]Returns reference to the CC[3] COMPARE event endpoint for PPI.
Generated when the counter is incremented and then matches the value
specified in the CC[3] register.